@@ -199,7 +199,16 @@ class Exchange():
                 raise ValueError(
                     f"""Cannot find any orbital for atom {iatom}, which is supposed to be magnetic. Please check the Wannier functions."""
                 )
-
+            nsorb=len(self.orb_dict[iatom])
+            if (not self._is_collinear) and nsorb % 2 != 0:
+                raise ValueError(
+                    f"""The number of spin-orbitals for atom {iatom} is not even,
+{nsorb} spin-orbitals are found near this atom.
+which means the spin up/down does not have same number of orbitals. 
+This is often because the Wannier functions are wrongly defined,
+or badly localized. Please check the Wannier centers in the Wannier90 output file. 
+"""
+                )
         self._spin_dict = {}
         self._atom_dict = {}
         for ispin, iatom in enumerate(self.ind_mag_atoms):
@@ -437,7 +446,7 @@ class ExchangeNCL(Exchange):
             for key, val in self.A_ijR_orb.items():
                 R, iatom, jatom = key
                 Rm = tuple(-x for x in R)
-                valm = self.A_ijR_orb[(Rm, jatom, iatom)]
+                #valm = self.A_ijR_orb[(Rm, jatom, iatom)]
                 ni = self.norb_reduced[iatom]
                 nj = self.norb_reduced[jatom]
 
@@ -454,7 +463,7 @@ class ExchangeNCL(Exchange):
                 for i in range(3):
                     for j in range(3):
                         Ja[i,
-                           j] = np.imag(val[i + 1, j + 1] + valm[i + 1, j + 1])
+                           j] = np.imag(val[i + 1, j + 1] + val[j + 1, i + 1])
                 # DMI
 
                 Dtmp = np.zeros((3, ni, nj), dtype=float)
@@ -652,6 +661,11 @@ class ExchangeNCL(Exchange):
         with open(fname, 'wb') as myfile:
             pickle.dump(result, myfile)
 
+    def validate(self):
+        """
+        Do some sanity check before proceding.
+        """
+
     def calculate_all(self):
         """
         The top level.
@@ -663,6 +677,8 @@ class ExchangeNCL(Exchange):
 
         AijRs_orb = {}
 
+        self.validate()
+
         npole = len(self.contour.path)
         if self.np > 1:
             #executor = ProcessPool(nodes=self.np)
